.. documentation master file, created by
   sphinx-quickstart on Sat Jan 21 19:11:14 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


.. include:: ../../README.rst

.. toctree::
   :maxdepth: 2

   getting_started.rst
   core.rst
   testing.rst
   dialogs.rst
   exceptions.rst
   examples/examples.rst
   development/index.rst
   history.rst

* :ref:`genindex`
